@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 __all__ = ['ANY_ARGUMENT',
            'ANY_ARGUMENTS',
@@ -40,13 +40,10 @@ from logging import getLogger
 from unittest import TestCase
 from types import ModuleType
 
-from fluentmock.exceptions import (CouldNotVerifyCallError,
-                                   FoundMatcherInNativeVerificationError,
-                                   HasBeenCalledAtLeastOnceError,
+from fluentmock.exceptions import (FoundMatcherInNativeVerificationError,
                                    InvalidAttributeError,
                                    InvalidUseOfAnyArgumentsError,
-                                   NoCallsStoredError,
-                                   HasBeenCalledWithUnexpectedArgumentsError)
+                                   VerificationError)
 from fluentmock.matchers import (AtLeastOnceMatcher,
                                  FluentMatcher,
                                  FluentAnyArguments,
@@ -128,6 +125,9 @@ class FluentCallEntry(object):
         if self.arguments and self.arguments[0] is ANY_ARGUMENTS:
             return True
 
+        if arguments and arguments[0] is ANY_ARGUMENTS:
+            return True
+
         if self.arguments == arguments and self.keyword_arguments == keyword_arguments:
             return True
 
@@ -299,7 +299,7 @@ class Verifier(FluentTarget):
             error_message = 'Argument times has to be a instance of {fluentmatcher}'.format(fluentmatcher=class_name)
             raise ValueError(error_message)
 
-        self._times = times
+        self._matcher = times
 
     def __getattr__(self, attribute_name):
         self.attribute_name = attribute_name
@@ -333,26 +333,29 @@ class Verifier(FluentTarget):
             for call_entry in _call_entries:
                 if call_entry.matches(self.object, self.attribute_name, arguments, keyword_arguments):
                     matching_call_entries += 1
+
         return matching_call_entries
 
+    def _ensure_valid_usage_of_any_arguments(self, arguments):
+        if arguments and ANY_ARGUMENTS in arguments:
+            if len(arguments) > 1:
+                raise InvalidUseOfAnyArgumentsError()
+
     def __call__(self, *arguments, **keyword_arguments):
+        self._ensure_valid_usage_of_any_arguments(arguments)
         matching_call_entries = self._count_matching_call_entries(arguments, keyword_arguments)
 
-        if self._times is NEVER and not NEVER.matches(matching_call_entries):
-            expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
-            raise HasBeenCalledAtLeastOnceError(expected_call_entry)
+        if self._matcher is AT_LEAST_ONCE and not AT_LEAST_ONCE.matches(matching_call_entries):
 
-        if self._times is AT_LEAST_ONCE and not AT_LEAST_ONCE.matches(matching_call_entries):
             method_of_mock = getattr(self.object, self.attribute_name)
             if isinstance(self.object, Mock) and isinstance(method_of_mock, Mock):
-                self._ensure_no_matchers_in_arguments(arguments, keyword_arguments)
-
                 method_of_mock.assert_called_with(*arguments, **keyword_arguments)
             else:
-                expected_call_entry = FluentCallEntry(self.object, self.attribute_name,
-                                                      arguments, keyword_arguments)
+                expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
+
                 if not _call_entries:
-                    raise NoCallsStoredError(expected_call_entry)
+                    raise VerificationError(expected_call_entry, self._matcher,
+                                            reason='No patched function has been called.')
 
                 found_calls = []
 
@@ -362,13 +365,11 @@ class Verifier(FluentTarget):
                         found_calls.append(call_entry)
 
                 if found_calls:
-                    if arguments and ANY_ARGUMENTS in arguments:
-                        if len(arguments) > 1:
-                            raise InvalidUseOfAnyArgumentsError()
-                        return
-                    raise HasBeenCalledWithUnexpectedArgumentsError(expected_call_entry, found_calls)
+                    raise VerificationError(expected_call_entry, self._matcher, found_calls=found_calls)
 
-                raise CouldNotVerifyCallError(expected_call_entry)
+        if not self._matcher.matches(matching_call_entries):
+            expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
+            raise VerificationError(expected_call_entry, self._matcher)
 
 
 def create_mock(*arguments, **keyword_arguments):
